==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/base/ibgmainwindowsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Toolkit-independent base for a main window subject class.
//

#ifndef IBGMAINWINDOWSUBJECT_H
#define IBGMAINWINDOWSUBJECT_H


class iString;

class iggDialog;
class iggFrame;
class iggFrameTopParent;
class iggMainWindow;
class iggRenderWindow;

class ibgWidgetProgressBarSubject;


class ibgMainWindowSubject
{

	friend class iggMainWindow;

public:

	virtual void AttachRenderWindow(iggRenderWindow *rw) = 0;

#ifdef I_DEBUG
	static void SetEmphasizeUnderCursor(bool s){ mEmphasizeUnderCursor = s; }
#endif

protected:

	ibgMainWindowSubject(iggMainWindow *owner);
	virtual ~ibgMainWindowSubject();

	//
	//  General members
	//
	virtual int PopupWindow(const iggFrame *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2) = 0;
	virtual void ShowToolTips(bool s) = 0;
	virtual void SetTheme(const iString &name) = 0;

	//
	//  Construction helpers
	//
	virtual void SetTopParentSubjects(iggFrameTopParent *busyIndicatorFrame, iggFrameTopParent *visitedFileListFrame) = 0;
	virtual void PopulateStatusBar(iggFrame *busyIndicatorFrame, ibgWidgetProgressBarSubject *progressBarSubject, iggFrame *visitedFileListFrame) = 0;

	//
	//  Docking helpers
	//
	virtual void PlaceWindowsInDockedPositions() = 0;
	virtual void RestoreWindowsFromDockedPositions() = 0;
	
	//
	//  Helper variables
	//
	iggMainWindow *mMainWindow;

#ifdef I_DEBUG
	static bool mEmphasizeUnderCursor;
#endif
};

#endif  // IBGMAINWINDOWSUBJECT_H

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/shells/base/ibgmainwindowsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Toolkit-independent base for a main window subject class.
//

#ifndef IBGMAINWINDOWSUBJECT_H
#define IBGMAINWINDOWSUBJECT_H


#include "ibgelement.h"


class iString;

class iggDialog;
class iggFrame;
class iggFrameTopParent;
class iggMainWindow;
class iggRenderWindow;

class ibgWidgetProgressBarSubject;


class ibgMainWindowSubject : public ibgElement
{

	friend class iggMainWindow;

public:

	virtual void AttachRenderWindow(iggRenderWindow *rw) = 0;

#ifdef I_DEBUG
	static void SetEmphasizeUnderCursor(bool s){ mEmphasizeUnderCursor = s; }
#endif

protected:

	ibgMainWindowSubject(iggMainWindow *owner);
	virtual ~ibgMainWindowSubject();

	//
	//  General members
	//
	virtual int PopupWindow(const iggFrame *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2) = 0;
	virtual int PopupWindow(const iggRenderWindow *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2) = 0;
	virtual void ShowToolTips(bool s) = 0;
	virtual void SetTheme(const iString &name) = 0;

	//
	//  Construction helpers
	//
	virtual void SetTopParentSubjects(iggFrameTopParent *busyIndicatorFrame, iggFrameTopParent *visitedFileListFrame) = 0;
	virtual void PopulateStatusBar(iggFrame *busyIndicatorFrame, ibgWidgetProgressBarSubject *progressBarSubject, iggFrame *visitedFileListFrame) = 0;

	//
	//  Docking helpers
	//
	virtual void PlaceWindowsInDockedPositions() = 0;
	virtual void RestoreWindowsFromDockedPositions() = 0;
	
	//
	//  Helper variables
	//
	iggMainWindow *mMainWindow;

#ifdef I_DEBUG
	static bool mEmphasizeUnderCursor;
#endif
};

#endif  // IBGMAINWINDOWSUBJECT_H
